@@ -29,16 +29,16 @@
 
 using Konsole::ZModemDialog;
 
-ZModemDialog::ZModemDialog(QWidget* aParent, bool modal, const QString& caption)
-    : QDialog(aParent)
+ZModemDialog::ZModemDialog(QWidget *aParent, bool modal, const QString &caption) :
+    QDialog(aParent)
 {
     setObjectName(QStringLiteral("zmodem_progress"));
     setModal(modal);
     setWindowTitle(caption);
 
     mButtonBox = new QDialogButtonBox(QDialogButtonBox::Close);
-    QWidget *mainWidget = new QWidget(this);
-    QVBoxLayout *mainLayout = new QVBoxLayout;
+    auto mainWidget = new QWidget(this);
+    auto mainLayout = new QVBoxLayout;
     setLayout(mainLayout);
     mainLayout->addWidget(mainWidget);
     mUser1Button = new QPushButton;
@@ -54,11 +54,14 @@ ZModemDialog::ZModemDialog(QWidget* aParent, bool modal, const QString& caption)
     _textEdit->setReadOnly(true);
     mainLayout->addWidget(_textEdit);
 
-    connect(this, &Konsole::ZModemDialog::user1Clicked, this, &Konsole::ZModemDialog::slotUser1Clicked);
-    connect(mButtonBox->button(QDialogButtonBox::Close), &QPushButton::clicked, this, &Konsole::ZModemDialog::slotClose);
+    connect(this, &Konsole::ZModemDialog::user1Clicked, this,
+            &Konsole::ZModemDialog::slotUser1Clicked);
+    connect(mButtonBox->button(QDialogButtonBox::Close),
+            &QPushButton::clicked, this,
+            &Konsole::ZModemDialog::slotClose);
 }
 
-void ZModemDialog::addProgressText(const QString& text)
+void ZModemDialog::addProgressText(const QString &text)
 {
     QTextCursor currentCursor = _textEdit->textCursor();
 
